@@ -298,7 +298,7 @@ impl Source {
                 "Could not decode the given audio data".to_string(),
             ));
         }
-        let sink = rodio::Sink::try_new(&context.audio_context.device())?;
+        let sink = rodio::Sink::try_new(context.audio_context.device())?;
         let cursor = io::Cursor::new(data);
         Ok(Source {
             sink,
@@ -388,7 +388,7 @@ impl SoundSource for Source {
         let volume = self.volume();
 
         let device = ctx.audio_context.device();
-        self.sink = rodio::Sink::try_new(&device)?;
+        self.sink = rodio::Sink::try_new(device)?;
         self.state.play_time.store(0, Ordering::SeqCst);
 
         // Restore information from the previous link.
@@ -457,7 +457,7 @@ impl SpatialSource {
             ));
         }
         let sink = rodio::SpatialSink::try_new(
-            &context.audio_context.device(),
+            context.audio_context.device(),
             [0.0, 0.0, 0.0],
             [-1.0, 0.0, 0.0],
             [1.0, 0.0, 0.0],
@@ -517,7 +517,7 @@ impl SoundSource for SpatialSource {
 
         let device = ctx.audio_context.device();
         let new_sink = rodio::SpatialSink::try_new(
-            &device,
+            device,
             self.emitter_position.into(),
             self.left_ear.into(),
             self.right_ear.into(),
@@ -569,7 +569,7 @@ impl SoundSource for SpatialSource {
 
         let device = ctx.audio_context.device();
         self.sink = rodio::SpatialSink::try_new(
-            &device,
+            device,
             self.emitter_position.into(),
             self.left_ear.into(),
             self.right_ear.into(),
