@@ -944,13 +944,13 @@ impl MeshBatch {
                 self.instance_buffer = Some(new_buffer);
 
                 ctx.gfx_context.encoder.update_buffer(
-                    &self.instance_buffer.as_ref().expect("Can never fail"),
+                    self.instance_buffer.as_ref().expect("Can never fail"),
                     new_properties.as_slice(),
                     0,
                 )?;
             } else {
                 ctx.gfx_context.encoder.update_buffer(
-                    &self.instance_buffer.as_ref().expect("Should never fail"),
+                    self.instance_buffer.as_ref().expect("Should never fail"),
                     new_properties.as_slice(),
                     first_param,
                 )?;
@@ -976,6 +976,21 @@ impl MeshBatch {
         if !self.instance_params.is_empty() {
             self.mesh.debug_id.assert(ctx);
 
+            // scale the offset according to the dimensions of the spritebatch
+            // but only if there is an offset (it's too expensive to calculate the dimensions to always to this)
+            let mut new_param = param;
+            if let Transform::Values { offset, .. } = param.trans {
+                if offset != [0.0, 0.0].into() {
+                    if let Some(dim) = self.dimensions(ctx) {
+                        let new_offset = mint::Vector2 {
+                            x: offset.x * dim.w + dim.x,
+                            y: offset.y * dim.h + dim.y,
+                        };
+                        new_param = param.offset(new_offset);
+                    }
+                }
+            }
+
             if !self.instance_params.is_empty() && self.instance_buffer_dirty {
                 self.flush(ctx)?;
             }
@@ -987,7 +1002,7 @@ impl MeshBatch {
 
             // In the batch we multiply the transform for each item in the batch
             // with the transform given in the `DrawParam` here.
-            let batch_transform = Matrix4::from(param.trans.to_bare_matrix());
+            let batch_transform = Matrix4::from(new_param.trans.to_bare_matrix());
             gfx.set_global_mvp(batch_transform)?;
 
             // HACK this code has to restore the old instance buffer after drawing,
@@ -1018,7 +1033,23 @@ impl MeshBatch {
 
     /// Returns a bounding box in the form of a `Rect`.
     pub fn dimensions(&self, ctx: &mut Context) -> Option<Rect> {
-        self.mesh.dimensions(ctx)
+        if self.instance_params.is_empty() {
+            return None;
+        }
+        if let Some(dimensions) = self.mesh.dimensions(ctx) {
+            self.instance_params
+                .iter()
+                .map(|&param| transform_rect(dimensions, param))
+                .fold(None, |acc: Option<Rect>, rect| {
+                    Some(if let Some(acc) = acc {
+                        acc.combine_with(rect)
+                    } else {
+                        rect
+                    })
+                })
+        } else {
+            None
+        }
     }
 
     /// Sets the blend mode to be used when drawing this drawable.
